summaryrefslogtreecommitdiffstats
path: root/sys/amd64/ia32
diff options
context:
space:
mode:
Diffstat (limited to 'sys/amd64/ia32')
-rw-r--r--sys/amd64/ia32/ia32_syscall.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/amd64/ia32/ia32_syscall.c b/sys/amd64/ia32/ia32_syscall.c
index c51a2be..40ec2e6 100644
--- a/sys/amd64/ia32/ia32_syscall.c
+++ b/sys/amd64/ia32/ia32_syscall.c
@@ -105,10 +105,10 @@ ia32_syscall(struct trapframe *frame)
ksiginfo_t ksi;
/*
* note: PCPU_LAZY_INC() can only be used if we can afford
* occassional inaccuracy in the count.
*/
- PCPU_LAZY_INC(cnt.v_syscall);
+ PCPU_INC(cnt.v_syscall);
td->td_pticks = 0;
td->td_frame = frame;
OpenPOWER on IntegriCloud
@@ -105,10 +105,10 @@ ia32_syscall(struct trapframe *frame)
ksiginfo_t ksi;
/*
- * note: PCPU_LAZY_INC() can only be used if we can afford
+ * note: PCPU_INC() can only be used if we can afford
* occassional inaccuracy in the count.
*/